@@ -1,9 +1,14 @@
-# fmt: off
-
 import warnings
 from operator import attrgetter
 from typing import (
-    TYPE_CHECKING, Iterable, Iterator, List, Optional, Sequence, Union, cast
+    TYPE_CHECKING,
+    Iterable,
+    Iterator,
+    List,
+    Optional,
+    Sequence,
+    Union,
+    cast,
 )
 
 import numpy as np
@@ -21,8 +26,6 @@ if TYPE_CHECKING:
     from ..data import Navaids  # noqa: 401
     from ..data.basic.airports import Airports  # noqa: 401
 
-# fmt: on
-
 
 class NavigationFeatures:
 
@@ -113,7 +116,7 @@ class NavigationFeatures:
         return guess_airport(data.iloc[0], **kwargs)
 
     def landing_at(self, airport: Union[str, "Airport"]) -> bool:
-        """Returns True if the flight takes off from the given airport."""
+        """Returns True if the flight lands at the given airport."""
 
         from ..core.structure import Airport
         from ..data import airports
@@ -908,18 +911,17 @@ class NavigationFeatures:
         if moving is None:
             return None
 
-        first_segment = next(
-            (
-                segment
-                for segment in moving.split("1T")
-                if segment.longer_than(time_threshold)
-            ),
-            None,
-        )
-        if first_segment is None:
+        segment = None
+        first_segment = None
+        for segment in moving.split("1T"):
+            if segment.longer_than(time_threshold) and first_segment is None:
+                first_segment = segment
+        last_segment = segment
+
+        if first_segment is None or last_segment is None:
             return None
 
-        return self.after(first_segment.start)
+        return self.between(first_segment.start, last_segment.stop)
 
     def pushback(
         self,
